.. include:: about.rst

.. toctree::
   :maxdepth: 3
   :caption: Introduction

   docs/install.rst
   docs/get_started.rst
   docs/terminology.rst

.. toctree::
   :maxdepth: 3
   :caption: Documentation

   docs/cli.rst
   docs/stack_group_config.rst
   docs/stack_config.rst
   docs/templates.rst
   docs/template_handlers.rst
   docs/hooks.rst
   docs/resolvers.rst
   docs/architecture.rst
   docs/permissions.rst

.. toctree::
   :maxdepth: 3
   :caption: Support

   docs/faq.rst


.. toctree::
   :maxdepth: 3
   :caption: API
   :glob:

   apidoc/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
